GetExportOutput

Struct GetExportOutput 

#[non_exhaustive]
pub struct GetExportOutput {
Show 15 fields pub export_arn: String, pub client_token: String, pub export_status: ExportStatus, pub domain_name: String, pub requested_at: DateTime, pub s3_bucket: String, pub s3_key_prefix: Option<String>, pub s3_sse_algorithm: Option<S3SseAlgorithm>, pub s3_sse_kms_key_id: Option<String>, pub s3_bucket_owner: Option<String>, pub failure_code: Option<String>, pub failure_message: Option<String>, pub export_manifest: Option<String>, pub items_count: Option<i64>, pub export_data_cutoff_time: Option<DateTime>, /* private fields */
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
export_arn: String

Unique ARN identifier of the export.

client_token: String

The client token provided for this export.

export_status: ExportStatus

The current state of the export. Current possible values include : PENDING - export request received, IN_PROGRESS - export is being processed, SUCCEEDED - export completed successfully, and FAILED - export encountered an error.

domain_name: String

The name of the domain that was exported.

requested_at: DateTime

Timestamp when the export request was received by the service.

s3_bucket: String

The name of the S3 bucket for this export.

s3_key_prefix: Option<String>

The S3 key prefix provided in the corresponding StartDomainExport request.

s3_sse_algorithm: Option<S3SseAlgorithm>

The S3 SSE encryption algorithm for this export.

s3_sse_kms_key_id: Option<String>

The KMS key ID for this export.

s3_bucket_owner: Option<String>

The S3 bucket owner account ID for this export.

failure_code: Option<String>

Failure code for the result of the failed export.

failure_message: Option<String>

Export failure reason description.

export_manifest: Option<String>

The name of the manifest summary file for the export.

items_count: Option<i64>

Total number of exported items.

export_data_cutoff_time: Option<DateTime>

The timestamp indicating the cutoff point for data inclusion in the export. All data inserted or modified before this time will be present in the exported data. Data insertions or modifications after this timestamp may or may not be present in the export.

Implementations

Source

impl GetExportOutput

pub fn export_arn(&self) -> &str

Unique ARN identifier of the export.

pub fn client_token(&self) -> &str

The client token provided for this export.

pub fn export_status(&self) -> &ExportStatus

The current state of the export. Current possible values include : PENDING - export request received, IN_PROGRESS - export is being processed, SUCCEEDED - export completed successfully, and FAILED - export encountered an error.

pub fn domain_name(&self) -> &str

The name of the domain that was exported.

pub fn requested_at(&self) -> &DateTime

Timestamp when the export request was received by the service.

pub fn s3_bucket(&self) -> &str

The name of the S3 bucket for this export.

pub fn s3_key_prefix(&self) -> Option<&str>

The S3 key prefix provided in the corresponding StartDomainExport request.

pub fn s3_sse_algorithm(&self) -> Option<&S3SseAlgorithm>

The S3 SSE encryption algorithm for this export.

pub fn s3_sse_kms_key_id(&self) -> Option<&str>

The KMS key ID for this export.

pub fn s3_bucket_owner(&self) -> Option<&str>

The S3 bucket owner account ID for this export.

pub fn failure_code(&self) -> Option<&str>

Failure code for the result of the failed export.

pub fn failure_message(&self) -> Option<&str>

Export failure reason description.

pub fn export_manifest(&self) -> Option<&str>

The name of the manifest summary file for the export.

pub fn items_count(&self) -> Option<i64>

Total number of exported items.

pub fn export_data_cutoff_time(&self) -> Option<&DateTime>

The timestamp indicating the cutoff point for data inclusion in the export. All data inserted or modified before this time will be present in the exported data. Data insertions or modifications after this timestamp may or may not be present in the export.

Source

impl GetExportOutput

pub fn builder() -> GetExportOutputBuilder

Creates a new builder-style object to manufacture GetExportOutput.