#[non_exhaustive]pub enum StartDomainExportError {
ConflictException(ConflictException),
InvalidParameterCombinationException(InvalidParameterCombinationException),
InvalidParameterValueException(InvalidParameterValueException),
NoSuchDomainException(NoSuchDomainException),
NumberExportsLimitExceeded(NumberExportsLimitExceeded),
Unhandled(Unhandled),
}Expand description
Error type for the StartDomainExportError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConflictException(ConflictException)
Indicates a conflict with one or more parameters of the request.
InvalidParameterCombinationException(InvalidParameterCombinationException)
Parameters that must not be used together were used together in the request.
InvalidParameterValueException(InvalidParameterValueException)
The specified parameter value is not valid.
NoSuchDomainException(NoSuchDomainException)
The specified domain does not exist.
NumberExportsLimitExceeded(NumberExportsLimitExceeded)
Cannot start export as export quota limit was exceeded
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl StartDomainExportError
impl StartDomainExportError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the StartDomainExportError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the StartDomainExportError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is StartDomainExportError::ConflictException.
Sourcepub fn is_invalid_parameter_combination_exception(&self) -> bool
pub fn is_invalid_parameter_combination_exception(&self) -> bool
Returns true if the error kind is StartDomainExportError::InvalidParameterCombinationException.
Sourcepub fn is_invalid_parameter_value_exception(&self) -> bool
pub fn is_invalid_parameter_value_exception(&self) -> bool
Returns true if the error kind is StartDomainExportError::InvalidParameterValueException.
Sourcepub fn is_no_such_domain_exception(&self) -> bool
pub fn is_no_such_domain_exception(&self) -> bool
Returns true if the error kind is StartDomainExportError::NoSuchDomainException.
Sourcepub fn is_number_exports_limit_exceeded(&self) -> bool
pub fn is_number_exports_limit_exceeded(&self) -> bool
Returns true if the error kind is StartDomainExportError::NumberExportsLimitExceeded.