StartDomainExportInput

Struct StartDomainExportInput 

#[non_exhaustive]
pub struct StartDomainExportInput { pub client_token: Option<String>, pub domain_name: Option<String>, pub s3_bucket: Option<String>, pub s3_key_prefix: Option<String>, pub s3_sse_algorithm: Option<S3SseAlgorithm>, pub s3_sse_kms_key_id: Option<String>, pub s3_bucket_owner: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
client_token: Option<String>

Providing a ClientToken makes the call to StartDomainExport API idempotent, meaning that multiple identical calls have the same effect as one single call. A client token is valid for 8 hours after the first request that uses it is completed. After 8 hours, any request with the same client token is treated as a new request. Do not resubmit the same request with the same client token for more than 8 hours, or the result might not be idempotent. If you submit a request with the same client token but a change in other parameters within the 8-hour idempotency window, a ConflictException will be returned.

domain_name: Option<String>

The name of the domain to export.

s3_bucket: Option<String>

The name of the S3 bucket where the domain data will be exported.

s3_key_prefix: Option<String>

The prefix string to be used to generate the S3 object keys for export artifacts.

s3_sse_algorithm: Option<S3SseAlgorithm>

The server-side encryption algorithm to use for the exported data in S3. Valid values are: AES256 (SSE-S3) and KMS (SSE-KMS). If not specified, bucket’s default encryption will apply.

s3_sse_kms_key_id: Option<String>

The KMS key ID to use for server-side encryption with AWS KMS-managed keys (SSE-KMS). This parameter is only expected with KMS as the S3 SSE algorithm.

s3_bucket_owner: Option<String>

The ID of the AWS account that owns the bucket the export will be stored in.

Implementations

Source

impl StartDomainExportInput

pub fn client_token(&self) -> Option<&str>

Providing a ClientToken makes the call to StartDomainExport API idempotent, meaning that multiple identical calls have the same effect as one single call. A client token is valid for 8 hours after the first request that uses it is completed. After 8 hours, any request with the same client token is treated as a new request. Do not resubmit the same request with the same client token for more than 8 hours, or the result might not be idempotent. If you submit a request with the same client token but a change in other parameters within the 8-hour idempotency window, a ConflictException will be returned.

pub fn domain_name(&self) -> Option<&str>

The name of the domain to export.

pub fn s3_bucket(&self) -> Option<&str>

The name of the S3 bucket where the domain data will be exported.

pub fn s3_key_prefix(&self) -> Option<&str>

The prefix string to be used to generate the S3 object keys for export artifacts.

pub fn s3_sse_algorithm(&self) -> Option<&S3SseAlgorithm>

The server-side encryption algorithm to use for the exported data in S3. Valid values are: AES256 (SSE-S3) and KMS (SSE-KMS). If not specified, bucket’s default encryption will apply.

pub fn s3_sse_kms_key_id(&self) -> Option<&str>

The KMS key ID to use for server-side encryption with AWS KMS-managed keys (SSE-KMS). This parameter is only expected with KMS as the S3 SSE algorithm.

pub fn s3_bucket_owner(&self) -> Option<&str>

The ID of the AWS account that owns the bucket the export will be stored in.

Source

impl StartDomainExportInput

pub fn builder() -> StartDomainExportInputBuilder

Creates a new builder-style object to manufacture StartDomainExportInput.