pub struct Client { /* private fields */ }Expand description
Client for Amazon SimpleDB v2
Client for invoking operations on Amazon SimpleDB v2. Each operation on Amazon SimpleDB v2 is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_simpledbv2::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_simpledbv2::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the GetExport operation has
a Client::get_export, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.get_export()
.export_arn("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Waiters
This client provides wait_until methods behind the Waiters trait.
To use them, simply import the trait, and then call one of the wait_until methods. This will
return a waiter fluent builder that takes various parameters, which are documented on the builder
type. Once parameters have been provided, the wait method can be called to initiate waiting.
For example, if there was a wait_until_thing method, it could look like:
let result = client.wait_until_thing()
.thing_id("someId")
.wait(Duration::from_secs(120))
.await;Implementations
Sourceimpl Client
impl Client
Sourcepub fn get_export(&self) -> GetExportFluentBuilder
pub fn get_export(&self) -> GetExportFluentBuilder
Constructs a fluent builder for the GetExport operation.
- The fluent builder is configurable:
export_arn(impl Into<String>)/set_export_arn(Option<String>):
required: true
Unique ARN identifier of the export.
- On success, responds with
GetExportOutputwith field(s):export_arn(String): Unique ARN identifier of the export.client_token(String): The client token provided for this export.export_status(ExportStatus): The current state of the export. Current possible values include : PENDING - export request received, IN_PROGRESS - export is being processed, SUCCEEDED - export completed successfully, and FAILED - export encountered an error.domain_name(String): The name of the domain that was exported.requested_at(DateTime): Timestamp when the export request was received by the service.s3_bucket(String): The name of the S3 bucket for this export.s3_key_prefix(Option<String>): The S3 key prefix provided in the corresponding StartDomainExport request.s3_sse_algorithm(Option<S3SseAlgorithm>): The S3 SSE encryption algorithm for this export.s3_sse_kms_key_id(Option<String>): The KMS key ID for this export.s3_bucket_owner(Option<String>): The S3 bucket owner account ID for this export.failure_code(Option<String>): Failure code for the result of the failed export.failure_message(Option<String>): Export failure reason description.export_manifest(Option<String>): The name of the manifest summary file for the export.items_count(Option<i64>): Total number of exported items.export_data_cutoff_time(Option<DateTime>): The timestamp indicating the cutoff point for data inclusion in the export. All data inserted or modified before this time will be present in the exported data. Data insertions or modifications after this timestamp may or may not be present in the export.
- On failure, responds with
SdkError<GetExportError>
Sourceimpl Client
impl Client
Sourcepub fn list_exports(&self) -> ListExportsFluentBuilder
pub fn list_exports(&self) -> ListExportsFluentBuilder
Constructs a fluent builder for the ListExports operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
domain_name(impl Into<String>)/set_domain_name(Option<String>):
required: false
The name of the domain to filter exports. If not provided, exports for all the domains will be listed.max_results(i32)/set_max_results(Option<i32>):
required: false
The maximum number of exports to return in a single response.next_token(impl Into<String>)/set_next_token(Option<String>):
required: false
A pagination token used to retrieve the next page of results. This token is obtained from the nextToken field in the previous ListExportsResponse. Leave empty for the first request.
- On success, responds with
ListExportsOutputwith field(s):export_summaries(Vec::<ExportSummary>): List of export summaries containing export ARN, status, request timestamp, and associated domain name.next_token(Option<String>): A pagination token indicating that more results are available. To retrieve the next page of results, provide this token in a subsequent ListExports request. If null or empty, there are no more results to retrieve.
- On failure, responds with
SdkError<ListExportsError>
Sourceimpl Client
impl Client
Sourcepub fn start_domain_export(&self) -> StartDomainExportFluentBuilder
pub fn start_domain_export(&self) -> StartDomainExportFluentBuilder
Constructs a fluent builder for the StartDomainExport operation.
- The fluent builder is configurable:
client_token(impl Into<String>)/set_client_token(Option<String>):
required: false
Providing a ClientToken makes the call to StartDomainExport API idempotent, meaning that multiple identical calls have the same effect as one single call. A client token is valid for 8 hours after the first request that uses it is completed. After 8 hours, any request with the same client token is treated as a new request. Do not resubmit the same request with the same client token for more than 8 hours, or the result might not be idempotent. If you submit a request with the same client token but a change in other parameters within the 8-hour idempotency window, a ConflictException will be returned.domain_name(impl Into<String>)/set_domain_name(Option<String>):
required: true
The name of the domain to export.s3_bucket(impl Into<String>)/set_s3_bucket(Option<String>):
required: true
The name of the S3 bucket where the domain data will be exported.s3_key_prefix(impl Into<String>)/set_s3_key_prefix(Option<String>):
required: false
The prefix string to be used to generate the S3 object keys for export artifacts.s3_sse_algorithm(S3SseAlgorithm)/set_s3_sse_algorithm(Option<S3SseAlgorithm>):
required: false
The server-side encryption algorithm to use for the exported data in S3. Valid values are: AES256 (SSE-S3) and KMS (SSE-KMS). If not specified, bucket’s default encryption will apply.s3_sse_kms_key_id(impl Into<String>)/set_s3_sse_kms_key_id(Option<String>):
required: false
The KMS key ID to use for server-side encryption with AWS KMS-managed keys (SSE-KMS). This parameter is only expected with KMS as the S3 SSE algorithm.s3_bucket_owner(impl Into<String>)/set_s3_bucket_owner(Option<String>):
required: false
The ID of the AWS account that owns the bucket the export will be stored in.
- On success, responds with
StartDomainExportOutputwith field(s):client_token(String): The client token that was provided in the request.export_arn(String): Unique ARN identifier of the export.requested_at(DateTime): Timestamp when the export request was received by the service.
- On failure, responds with
SdkError<StartDomainExportError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.